@@ -176,25 +176,50 @@ sub escape_html {
   return $value;
 }
 
+sub _do_attr {
+  my ($self, $attr, $val) = @_;
+  if($attr eq ':content') {
+    $self->fill($val);
+  } elsif(
+    ($attr eq 'checked')
+    || ($attr eq 'selected')
+    || ($attr eq 'hidden')
+  ) {
+    $self->attr($attr=>'on');
+  } else {
+    $self->attr($attr=>$val);
+  }
+}
+
+sub _do {
+  my ($self, $maybe_attr, $action) = @_;
+  if($maybe_attr) {
+    die "Current selected element is not a tag" unless $self->tag;
+    if($maybe_attr eq '*') {
+      die 'action must be a hashref' unless ref($action) eq 'HASH';
+      map { $self->_do_attr($_, $action->{$_}) } keys %$action;
+    } else {
+      $self->_do_attr($maybe_attr => $action);
+    }
+  } elsif(!ref $action) {
+    my $escaped = escape_html $action;
+    $self->content($escaped);
+  } else {
+    $self->fill($action);
+  }
+}
+
 sub do {
   my $self = shift;
   while(@_) {
     my ($matchspec, $action) = (shift, shift);
     my ($css, $maybe_attr) = split('@', $matchspec);
-    $self->find($css)
-      ->each(sub {
-          if($maybe_attr) {
-            $_->attr($maybe_attr => $action);
-          } elsif(!ref $action) {
-            warn "zzz" x 100;
-            my $escaped = escape_html $action;
-            warn "$action ... $escaped";
-            $_->content($escaped);
-          } else {
-            $_->fill($action);
-          }
-        }
-      );
+    if($css ne '.') {
+      $self->find($css)
+        ->each(sub { $_->_do($maybe_attr, $action) });
+    } else {
+      $self->_do($maybe_attr, $action);
+    }
   }
   return $self;
 }
@@ -211,7 +236,6 @@ sub target { shift->attribute_helper('target', @_) }
 sub src { shift->attribute_helper('src', @_) }
 sub href { shift->attribute_helper('href', @_) }
 sub id { shift->attribute_helper('id', @_) }
-sub class { shift->attribute_helper('class', @_) }
 sub action { shift->attribute_helper('action', @_) }
 sub method { shift->attribute_helper('method', @_) }
 sub colspan { shift->attribute_helper('colspan', @_) }
@@ -220,6 +244,17 @@ sub enctype { shift->attribute_helper('enctype', @_) }
 sub formaction { shift->attribute_helper('formaction', @_) }
 sub headers { shift->attribute_helper('headers', @_) }
 sub size { shift->attribute_helper('size', @_) }
+sub value { shift->attribute_helper('value', @_) }
+
+sub class {
+  my ($self, @proto) = @_;
+  if(ref($proto[0]) eq 'HASH') {
+    my $classes = join ' ', grep { $proto[0]->{$_} } keys %{$proto[0]};
+    return $self->attribute_helper('class', $classes);
+  } else {
+    return $self->attribute_helper('class',@proto);
+  }
+}
 
 sub boolean_attribute_helper {
   my ($self, $name, $value) = @_;
@@ -616,6 +651,9 @@ fill that attribute.
 Additionally if the action is a simple, scalar value we automatically HTML escape
 it for you
 
+B<NOTE> if you want to set content or attributes on the DOM that ->do is run on
+you can use '.' as the match specification.
+
 =head1 ATTRIBUTE HELPERS
 
 The following methods are intended to make setting standard attributes on
@@ -630,8 +668,6 @@ it easier to chain several calls.
 
 =head2 id
 
-=head2 class
-
 =head2 action
 
 =head2 method
@@ -648,8 +684,7 @@ it easier to chain several calls.
 
 =head2 colspan
 
-s
-
+=head2 value
 
 Example
 
@@ -668,6 +703,24 @@ These attribute helpers have a special feature, since its basically a boolean at
 will check the passed value for its truth state, setting the attribute value to 'on'
 when true, but NOT setting the attribute at all if its false.
 
+=head2 class
+
+This attribute helper has a special shortcup to make it easier to programmtically set
+several classes based on a property.  If your argument is a hashref, all the keys whose
+values are true will be added.  For example:
+
+    my $dom = Template::Lace::DOM->new('<html><div>aaa</div></html>');
+
+    $dom->at('div')->class({ completed=>1, selected=>0});
+
+    print $dom;
+
+Returns:
+
+    <html><div class="completed">aaa</div></html>
+
+Useful to reduce some boilerplate.
+
 =head1 UNIQUE TAG HELPERS
 
 Helpers to access tags that are 'unique', typically only appearing
